==> jc-1.4.0.tar.gz: java/security/spec/DSAParameterSpec.h <==
// public class java.security.spec.DSAParameterSpec

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 96064ba9ffd4a2f9 java_security_spec_DSAParameterSpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_spec_DSAParameterSpec_H_
#define _JC_java_security_spec_DSAParameterSpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_java_security_spec_DSAParameterSpec$sub_refs	_jc_java_security_spec_DSAParameterSpec$sub_refs;
typedef struct _jc_java_security_spec_DSAParameterSpec$sub_nonrefs	_jc_java_security_spec_DSAParameterSpec$sub_nonrefs;
typedef struct _jc_java_security_spec_DSAParameterSpec$refs	_jc_java_security_spec_DSAParameterSpec$refs;
typedef struct _jc_java_security_spec_DSAParameterSpec$nonrefs	_jc_java_security_spec_DSAParameterSpec$nonrefs;
typedef struct _jc_java_security_spec_DSAParameterSpec$object	_jc_java_security_spec_DSAParameterSpec$object;

typedef const struct _jc_java_security_spec_DSAParameterSpec$vmethods	_jc_java_security_spec_DSAParameterSpec$vmethods;
typedef const struct _jc_java_security_spec_DSAParameterSpec$vtable	_jc_java_security_spec_DSAParameterSpec$vtable;
typedef const struct _jc_java_security_spec_DSAParameterSpec$vtype	_jc_java_security_spec_DSAParameterSpec$vtype;

// Constructors
extern void _jc_java_security_spec_DSAParameterSpec$method$_init$6cf26681d886fcf0(_jc_env *, struct _jc_java_security_spec_DSAParameterSpec$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *);

// Virtual methods
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_DSAParameterSpec$method$getG$59cffd735b56d8ad(_jc_env *, struct _jc_java_security_spec_DSAParameterSpec$object *);
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_DSAParameterSpec$method$getP$612c6062f1779963(_jc_env *, struct _jc_java_security_spec_DSAParameterSpec$object *);
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_DSAParameterSpec$method$getQ$e08c53541a87120d(_jc_env *, struct _jc_java_security_spec_DSAParameterSpec$object *);
extern void _jc_java_security_spec_DSAParameterSpec$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_security_spec_DSAParameterSpec$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_spec_DSAParameterSpec$method_info$getG$59cffd735b56d8ad;
extern _jc_method _jc_java_security_spec_DSAParameterSpec$method_info$getP$612c6062f1779963;
extern _jc_method _jc_java_security_spec_DSAParameterSpec$method_info$getQ$e08c53541a87120d;
extern _jc_method _jc_java_security_spec_DSAParameterSpec$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_security_spec_DSAParameterSpec$vmethods {
	struct _jc_java_math_BigInteger$object	*(*getG$59cffd735b56d8ad)(_jc_env *, struct _jc_java_security_spec_DSAParameterSpec$object *);
	struct _jc_java_math_BigInteger$object	*(*getP$612c6062f1779963)(_jc_env *, struct _jc_java_security_spec_DSAParameterSpec$object *);
	struct _jc_java_math_BigInteger$object	*(*getQ$e08c53541a87120d)(_jc_env *, struct _jc_java_security_spec_DSAParameterSpec$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_security_spec_DSAParameterSpec$object *);
};

// Vtable
struct _jc_java_security_spec_DSAParameterSpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_spec_DSAParameterSpec$vmethods	java_security_spec_DSAParameterSpec;
};

// Vtype
struct _jc_java_security_spec_DSAParameterSpec$vtype {
	_jc_type			type;
	_jc_java_security_spec_DSAParameterSpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_spec_DSAParameterSpec$sub_refs {
	struct _jc_java_math_BigInteger$object	*p;
	struct _jc_java_math_BigInteger$object	*q;
	struct _jc_java_math_BigInteger$object	*g;
};

// Reference instance fields (object)
struct _jc_java_security_spec_DSAParameterSpec$refs {
    _jc_java_security_spec_DSAParameterSpec$sub_refs	java_security_spec_DSAParameterSpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_spec_DSAParameterSpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_spec_DSAParameterSpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_spec_DSAParameterSpec$sub_nonrefs	java_security_spec_DSAParameterSpec;
};

// Object instance structure
struct _jc_java_security_spec_DSAParameterSpec$object {
	_jc_java_security_spec_DSAParameterSpec$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_spec_DSAParameterSpec$vtype	*vtype;
	_jc_java_security_spec_DSAParameterSpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_spec_DSAParameterSpec$vtype _jc_java_security_spec_DSAParameterSpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_spec_DSAParameterSpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_spec_DSAParameterSpec$class_object;

#endif	/* _JC_java_security_spec_DSAParameterSpec_H_ */

==> jc-1.4.6.tar.gz: java/security/spec/DSAParameterSpec.h <==
// public class java.security.spec.DSAParameterSpec

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 96064ba9ffd4a2f9 java_security_spec_DSAParameterSpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_spec_DSAParameterSpec_H_
#define _JC_java_security_spec_DSAParameterSpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_java_security_spec_DSAParameterSpec$sub_refs	_jc_java_security_spec_DSAParameterSpec$sub_refs;
typedef struct _jc_java_security_spec_DSAParameterSpec$sub_nonrefs	_jc_java_security_spec_DSAParameterSpec$sub_nonrefs;
typedef struct _jc_java_security_spec_DSAParameterSpec$refs	_jc_java_security_spec_DSAParameterSpec$refs;
typedef struct _jc_java_security_spec_DSAParameterSpec$nonrefs	_jc_java_security_spec_DSAParameterSpec$nonrefs;
typedef struct _jc_java_security_spec_DSAParameterSpec$object	_jc_java_security_spec_DSAParameterSpec$object;

typedef const struct _jc_java_security_spec_DSAParameterSpec$vmethods	_jc_java_security_spec_DSAParameterSpec$vmethods;
typedef const struct _jc_java_security_spec_DSAParameterSpec$vtable	_jc_java_security_spec_DSAParameterSpec$vtable;
typedef const struct _jc_java_security_spec_DSAParameterSpec$vtype	_jc_java_security_spec_DSAParameterSpec$vtype;

// Constructors
extern void _jc_java_security_spec_DSAParameterSpec$method$_init$6cf26681d886fcf0(_jc_env *, struct _jc_java_security_spec_DSAParameterSpec$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_DSAParameterSpec$method$getG$59cffd735b56d8ad(_jc_env *, struct _jc_java_security_spec_DSAParameterSpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_DSAParameterSpec$method$getP$612c6062f1779963(_jc_env *, struct _jc_java_security_spec_DSAParameterSpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_java_security_spec_DSAParameterSpec$method$getQ$e08c53541a87120d(_jc_env *, struct _jc_java_security_spec_DSAParameterSpec$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_spec_DSAParameterSpec$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_security_spec_DSAParameterSpec$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_spec_DSAParameterSpec$method_info$getG$59cffd735b56d8ad;
extern _jc_method _jc_java_security_spec_DSAParameterSpec$method_info$getP$612c6062f1779963;
extern _jc_method _jc_java_security_spec_DSAParameterSpec$method_info$getQ$e08c53541a87120d;
extern _jc_method _jc_java_security_spec_DSAParameterSpec$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_security_spec_DSAParameterSpec$vmethods {
	struct _jc_java_math_BigInteger$object	*(*getG$59cffd735b56d8ad)(_jc_env *, struct _jc_java_security_spec_DSAParameterSpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getP$612c6062f1779963)(_jc_env *, struct _jc_java_security_spec_DSAParameterSpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getQ$e08c53541a87120d)(_jc_env *, struct _jc_java_security_spec_DSAParameterSpec$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_security_spec_DSAParameterSpec$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_spec_DSAParameterSpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_spec_DSAParameterSpec$vmethods	java_security_spec_DSAParameterSpec;
};

// Vtype
struct _jc_java_security_spec_DSAParameterSpec$vtype {
	_jc_type			type;
	_jc_java_security_spec_DSAParameterSpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_spec_DSAParameterSpec$sub_refs {
	struct _jc_java_math_BigInteger$object	*p;
	struct _jc_java_math_BigInteger$object	*q;
	struct _jc_java_math_BigInteger$object	*g;
};

// Reference instance fields (object)
struct _jc_java_security_spec_DSAParameterSpec$refs {
    _jc_java_security_spec_DSAParameterSpec$sub_refs	java_security_spec_DSAParameterSpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_spec_DSAParameterSpec$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_security_spec_DSAParameterSpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_spec_DSAParameterSpec$sub_nonrefs	java_security_spec_DSAParameterSpec;
};

// Object instance structure
struct _jc_java_security_spec_DSAParameterSpec$object {
	_jc_java_security_spec_DSAParameterSpec$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_spec_DSAParameterSpec$vtype	*vtype;
	_jc_java_security_spec_DSAParameterSpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_spec_DSAParameterSpec$vtype _jc_java_security_spec_DSAParameterSpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_spec_DSAParameterSpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_spec_DSAParameterSpec$class_object;

#endif	/* _JC_java_security_spec_DSAParameterSpec_H_ */
